==> vtigercrm-5.3.0p0.tgz: vtigercrm/modules/Reports/language/en_us.lang.php <==
<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 * Contributor(s): ______________________________________.
 ********************************************************************************/
/*********************************************************************************
 * $Header:  
 * Description:  Defines the English language pack for the Account module.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.
 * All Rights Reserved.
 * Contributor(s): ______________________________________..
 ********************************************************************************/

$mod_strings = Array(
'LBL_MODULE_NAME'=>'Reports',
'LBL_MODULE_TITLE'=>'Reports: Home',
'LBL_CREATE_REPORT'=>'Create Report',
'LBL_CUSTOMIZE_REPORT'=>'Customize Report',
'LBL_REP_BUTTON'=>'Create New Report',
'LBL_REP_FOLDER_BUTTON'=>'Create New Report Folder',
'LBL_REP_FOLDER'=>'Report Folder',
'LBL_REP_FOLDER_DTLS'=>'Folder Details',
'LBL_REP_FOLDER_NAME'=>'Folder Name:',
'LBL_REP_FOLDER_DESC'=>'Folder Description:',
'LBL_NEW_REP0_HDR1'=>'Select a Module for which a new Report has to be created:',
'LBL_NEW_REP0_HDR2'=>'Select Related Module:',
'LBL_NEW_REP0_HDR3'=>'Note:',
'LBL_NEW_REP0_HDR4'=>'Report Module and related module once selected cannot be modified later',
'LBL_CONTINUE_BUTTON'=>'Continue',
'LBL_NEW_REP1_HDR1'=>'Provide the following report information',
'LBL_SELECT_COLUMNS'=>'Select Columns',
'LBL_SPECIFY_GROUPING'=>'Specify Grouping',
'LBL_COLUMNS_TO_TOTAL'=>'Choose Columns To Total',
'LBL_SPECIFY_CRITERIA'=>'Specify Criteria',
'LBL_SAVERUN_BUTTON'=>'Save And Run',
'LBL_TABULAT_REPORT'=>'Tabular Report',
'LBL_REPORT_TYPE_HDR1'=>'Tabular reports are the simplest and fastest way to get a listing of your data.',
'LBL_SUMMARY_REPORT'=>'Summary Report',
'LBL_REPORT_TYPE_HDR2'=>'Summary reports allow you to view your data along with subtotals and other summary information.',
'LBL_AVAILABLE_COLUMNS'=>'Available Columns:',
'LBL_SELECTED_COLUMNS'=>'Selected Columns:',
'LBL_ADD_BUTTON'=>'Add',
'LBL_COLUMNS'=>'Columns',
'LBL_COLUMNS_SUM'=>'Sum',
'LBL_COLUMNS_AVERAGE'=>'Average',
'LBL_COLUMNS_LOW_VALUE'=>'Lowest Value',
'LBL_COLUMNS_LARGE_VALUE'=>'Largest Value',
'LBL_NONE'=>'None',
'LBL_GROUPING_SORT'=>'Sort Order:',
'LBL_GROUPING_SUMMARIZE'=>'Summarize information by:',
'LBL_GROUPING_THEN_BY'=>'and then by:',
'LBL_GROUPING_FINALLY_BY'=>'and finally by:',
'LBL_ADVANCED_FILTER'=>'Advanced Filters',
'LBL_STANDARD_FILTER'=>'Standard Filters',
'LBL_SF_COLUMNS'=>'Column',
'LBL_SF_STARTDATE'=>'Start Date',
'LBL_SF_ENDDATE'=>'End Date',
'LBL_AF_HDR1'=>'Set the search conditions to further restrict the list.',
'LBL_AF_HDR2'=>'You can use &quot;or&quot; filters by entering multiple items in the third column.',
'LBL_AF_HDR3'=>'You can enter up to 10 items, separated by commas. For example: CA, NY, TX, FL searches for CA or NY or TX or FL.',
'LBL_FILTER_OPTIONS'=>'Filter Options',
'LBL_CUSTOMIZE_BUTTON'=>'Customize',
'LBL_EXPORTPDF_BUTTON'=>'Export To PDF',
'LBL_APPLYFILTER_BUTTON'=>'Apply Filter',
'LBL_GENERATED_REPORT'=>'Generated Report',
'LBL_GRAND_TOTAL'=>'Grand Total',

//Added for 4.2 Patch I
'LBL_EXPORTXL_BUTTON'=>'Export To Excel',

//Added for 5 Beta
'LBL_NO_PERMISSION'=>'Your profile dosen\'t allow you view the reports for one of the  module(s)',
'LBL_SELECT_COLUMNS_TO_GENERATE_REPORTS'=>'Select columns to generate reports',
'LBL_AVAILABLE_FIELDS'=>'Available Fields',
'LBL_SELECTED_FIELDS'=>'Selected Fields',
'LBL_CALCULATIONS'=>'Calculations',
'LBL_SELECT_COLUMNS_TO_TOTAL'=>'Select columns to Total',
'LBL_SELECT_FILTERS_TO_STREAMLINE_REPORT_DATA'=>'Select Filters to Streamline Report Data',
'LBL_SELECT_FILTERS'=>'Filters',
'LBL_SELECT_COLUMNS_TO_GROUP_REPORTS'=>'Select columns to group reports',
'LBL_BACK_TO_REPORTS'=>'Back to Reports',
'LBL_SELECT_ANOTHER_REPORT'=>'Select Another Report',
'LBL_SELECT_COLUMN'=>'Select Column',
'LBL_SELECT_TIME'=>'Select Time',
'LBL_PRINT_REPORT'=>'Print Report',
'LBL_CLICK_HERE'=>'Click Here',
'LBL_TO_ADD_NEW_GROUP'=>'to add new folder',
'LBL_CREATE_NEW'=>'Create New',
'LBL_RELATIVE_MODULE'=>'Related Module',
'LBL_REPORT_TYPE'=>'Report Type',
'LBL_REPORT_DETAILS'=>'Report Details',
'LBL_TYPE_THE_NAME'=>'Type the Name',
'LBL_DESCRIPTION_FOR_REPORT'=>'Description for the report',
'LBL_REPORT_NAME'=>'Report Name',
'LBL_DESCRIPTION'=>'Description',
'LBL_TOOLS'=>'Tools',
'LBL_AND'=>'and',
'LBL_ADD_NEW_GROUP'=>'Add New Folder',
'LBL_REPORT_MODULE'=>'Report Module',
'LBL_SELECT_RELATIVE_MODULE_FOR_REPORT'=>'Select Related Module for Report',
'LBL_SELECT_REPORT_TYPE_BELOW'=>'Select Report type Below',
'LBL_TABULAR_FORMAT'=>'Tabular Format',
'LBL_TABULAR_REPORTS_ARE_SIMPLEST'=>'Tabular Reports are the simplest and fastest way of getting your data',
'LBL_SUMMARY_REPORT_VIEW_DATA_WITH_SUBTOTALS'=>'Summary reports allow you to view your data along with subtotals and other summary information',
'LBL_FILTERS'=>'Filters',
'LBL_MOVE_TO'=>'Move to',
'LBL_RENAME_FOLDER'=>'Rename Folder',
'LBL_DELETE_FOLDER'=>'Delete Folder',

'Account and Contact Reports'=>'Account and Contact Reports',
'Lead Reports'=>'Lead Reports',
'Potential Reports'=>'Potential Reports',
'Activity Reports'=>'Activity Reports',
'HelpDesk Reports'=>'Trouble Tickets Reports',
'Product Reports'=>'Product Reports',
'Quote Reports'=>'Quote Reports',
'PurchaseOrder Reports'=>'PurchaseOrder Reports',
'SalesOrder Reports'=>'SalesOrder Reports', //Added for SO
'Invoice Reports'=>'Invoice Reports',
'Campaign Reports'=>'Campaign Reports', //Added for Campaigns 
'Contacts by Accounts'=>'Contacts by Accounts',
'Contacts without Accounts'=>'Contacts without Accounts',
'Contacts by Potentials'=>'Contacts by Potentials',
'Contacts related to Accounts'=>'Contacts related to Accounts',
'Contacts not related to Accounts'=>'Contacts not related to Accounts',
'Contacts related to Potentials'=>'Contacts related to Potentials',
'Lead by Source'=>'Lead by Source',
'Lead Status Report'=>'Lead Status Report',
'Potential Pipeline'=>'Potential Pipeline',
'Closed Potentials'=>'Closed Potentials',
'Potential that have Won'=>'Potential that have Won',
'Tickets by Products'=>'Tickets by Products',
'Tickets by Priority'=>'Tickets by Priority',
'Open Tickets'=>'Open Tickets',
'Tickets related to Products'=>'Tickets related to Products',
'Tickets that are Open'=>'Tickets that are Open',
'Product Details'=>'Product Details',
'Products by Contacts'=>'Products by Contacts',
'Product Detailed Report'=>'Product Detailed Report',
'Products related to Contacts'=>'Products related to Contacts',
'Open Quotes'=>'Open Quotes',
'Quotes Detailed Report'=>'Quotes Detailed Report',
'Quotes that are Open'=>'Quotes that are Open',
'PurchaseOrder by Contacts'=>'PurchaseOrder by Contacts',
'PurchaseOrder Detailed Report'=>'PurchaseOrder Detailed Report',
'PurchaseOrder related to Contacts'=>'PurchaseOrder related to Contacts',
'Invoice Detailed Report'=>'Invoice Detailed Report',
'Last Month Activities'=>'Last Month Activities',
'This Month Activities'=>'This Month Activities',
'Campaign Expectations and Actuals'=>'Campaign Expectations and Actuals', //Added for Campaigns
'SalesOrder Detailed Report'=>'SalesOrder Detailed Report', //Added for SO

'LBL_DELETE'=>'Delete',
'Create_Reports'=>'Create Reports',
'Create_New_Folder'=>'Create New Folder',
'Move_Reports'=>'Move Reports',
'Delete_Report'=>'Delete Report', 

'Custom'=>'Custom',
'Previous FY'=>'Previous FY', 
'Current FY'=>'Current FY',
'Next FY'=>'Next FY',
'Previous FQ'=>'Previous FQ',
'Current FQ'=>'Current FQ',
'Next FQ'=>'Next FQ',
'Yesterday'=>'Yesterday',
'Today'=>'Today',
'Tomorrow'=>'Tomorrow',
'Last Week'=>'Last Week',
'Current Week'=>'Current Week',
'Next Week'=>'Next Week',
'Last Month'=>'Last Month',
'Current Month'=>'Current Month',
'Next Month'=>'Next Month',
'Last 7 Days'=>'Last 7 Days',
'Last 30 Days'=>'Last 30 Days',
'Last 60 Days'=>'Last 60 Days',
'Last 90 Days'=>'Last 90 Days',
'Last 120 Days'=>'Last 120 Days',
'Next 7 Days'=>'Next 7 Days',
'Next 30 Days'=>'Next 30 Days',
'Next 60 Days'=>'Next 60 Days',
'Next 90 Days'=>'Next 90 Days',
'Next 120 Days'=>'Next 120 Days',
'TITLE_VTIGERCRM_CREATE_REPORT' => 'vtiger CRM - Create Report',
'TITLE_VTIGERCRM_PRINT_REPORT' => 'vtiger -  Print Report',
'NO_FILTER_SELECTED' => 'No filter Selected',

'LBL_GENERATE_NOW'=>'Generate Now',
'Totals'=>'Field Names',
'SUM'=>'SUM',
'AVG'=>'AVG',
'MAX'=>'MAX',
'MIN'=>'MIN',
'LBL_CUSTOM_REPORTS'=>'Custom Reports',

'ticketid'=>'Ticket Id',
'NO_COLUMN'=>'No Columns available to Total',

// Added/Updated for vtiger CRM 5.0.4
'LBL_REPORT_DELETED' => 'The report you are trying to view has been deleted.',

//Added for Reports
'LBL_SHARING'=>'Sharing',
'SELECT_FILTER_TYPE'=>'Select Report Type',
'LBL_USERS'=>'Users',
'LBL_GROUPS'=>'Groups',
'LBL_SELECT_FIELDS'=>'Select Fields',
'LBL_MEMBERS'=>'Members',
'LBL_RELATED_FIELDS'=>'Related Fields',
'LBL_NO_ACCESS'=>' Access Denied for module(s) ',
'LBL_NOT_ACTIVE'=>' Access Denied for module(s) ',
'LBL_PERM_DENIED'=>' Permission Denied for Report(s): ',
'LBL_FLDR_NOT_EMPTY'=>'Folder you are trying to delete is not Empty, Move or Delete the Reports in it.',
'NO_REL_MODULES'=>'No Related Modules for the Selected Module',
'LBL_REPORT_GENERATION_FAILED'=>'Report generation failed!',

'LBL_SHARING_TYPE'=>'Sharing Type',
'LBL_SELECT_REPORT_TYPE_TO_CONTROL_ACCESS'=>'Select Sharing Type to Control Access to the Report', 
'LBL_ACTION' => 'Action',
'LBL_VIEW_DETAILS' => 'View Details',
'LBL_SHOW_STANDARD_FILTERS' => 'Show Standard Filters',
'LBL_YEAR' => 'Year',
'LBL_MONTH'=> 'Month',
'LBL_QUARTER'=> 'Quarter',
'LBL_NONE'=> 'None',

'LBL_ROLES'=>'Roles',
'LBL_ROLES_SUBORDINATES'=>'Roles and Subordinates',
'LBL_SCHEDULE_EMAIL'=>'Schedule Email',
'LBL_SCHEDULE_EMAIL_DESCRIPTION'=>'Schedule Report to be sent to the selected Recipients at regular intervals through email',
'LBL_USERS_AVAILABEL'=> 'Recipients',
'LBL_REPORT_FORMAT_PDF'=> 'PDF',
'LBL_REPORT_FORMAT_EXCEL'=> 'EXCEL',
'LBL_REPORT_FORMAT_BOTH'=> 'Both',
'LBL_REPORT_FORMAT'=> 'Report Format',
'LBL_USERS_SELECTED'=>'Selected Recipients',
'LBL_SELECT'=>'Select',
'Hourly'=>'Hourly',
'Daily'=>'Daily',
'Weekly'=>'Weekly',
'BiWeekly'=>'BiWeekly',
'Monthly'=>'Monthly',
'Annually'=>'Annually',
'LBL_SCHEDULE_REPORT'=>'Schedule Report',
'LBL_SCHEDULE_FREQUENCY'=>'Frequency',
'OPTION_SCHEDULE_EMAIL_CHOOSE'=>'Choose ..... ',
'LBL_SCHEDULE_EMAIL_TIME'=>'Time',
'LBL_SCHEDULE_EMAIL_DOW'=>'DOW',
'LBL_SCHEDULE_EMAIL_DAY'=>'Day',
'LBL_SCHEDULE_EMAIL_MONTH'=>'Month',
'WEEKDAY_STRINGS' => array('Sunday','Monday','Tuesday','Wednesday','Thursday','Friday','Saturday'),
'MONTH_STRINGS' => array('January','February','March','April','May','June','July','August','September','October','November','December'),

'LBL_AUTO_GENERATED_REPORT_EMAIL' => 'This is an auto-generated email sent on behalf of a scheduled report.',
'LBL_TIME_FORMAT_MSG' => 'hh:mm (24 hour format)',

'LBL_SAVE_REPORT' => 'Save',
'LBL_SAVE_REPORT_AS' => 'Save Report as...',
)

?>

==> vtigercrm-5.4.0.tgz: vtigercrm/modules/Reports/language/en_us.lang.php <==
<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 * Contributor(s): ______________________________________.
 ********************************************************************************/
/*********************************************************************************
 * $Header:
 * Description:  Defines the English language pack for the Reports module.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.
 * All Rights Reserved.
 * Contributor(s): ______________________________________..
 ********************************************************************************/

$mod_strings = Array(
'LBL_MODULE_NAME'=>'Reports',
'LBL_MODULE_TITLE'=>'Reports: Home',
'LBL_CREATE_REPORT'=>'Create Report',
'LBL_CUSTOMIZE_REPORT'=>'Customize Report',
'LBL_REP_BUTTON'=>'Create New Report',
'LBL_REP_FOLDER_BUTTON'=>'Create New Report Folder',
'LBL_REP_FOLDER'=>'Report Folder',
'LBL_REP_FOLDER_DTLS'=>'Folder Details',
'LBL_REP_FOLDER_NAME'=>'Folder Name:',
'LBL_REP_FOLDER_DESC'=>'Folder Description:',
'LBL_NEW_REP0_HDR1'=>'Select a Module for which a new Report has to be created:',
'LBL_NEW_REP0_HDR2'=>'Select Related Module:',
'LBL_NEW_REP0_HDR3'=>'Note:',
'LBL_NEW_REP0_HDR4'=>'Report Module and related module once selected cannot be modified later',
'LBL_CONTINUE_BUTTON'=>'Continue',
'LBL_NEW_REP1_HDR1'=>'Provide the following report information',
'LBL_SELECT_COLUMNS'=>'Select Columns',
'LBL_SPECIFY_GROUPING'=>'Specify Grouping',
'LBL_COLUMNS_TO_TOTAL'=>'Choose Columns To Total',
'LBL_SPECIFY_CRITERIA'=>'Specify Criteria',
'LBL_SAVERUN_BUTTON'=>'Save And Run',
'LBL_TABULAT_REPORT'=>'Tabular Report',
'LBL_REPORT_TYPE_HDR1'=>'Tabular reports are the simplest and fastest way to get a listing of your data.',
'LBL_SUMMARY_REPORT'=>'Summary Report',
'LBL_REPORT_TYPE_HDR2'=>'Summary reports allow you to view your data along with subtotals and other summary information.',
'LBL_AVAILABLE_COLUMNS'=>'Available Columns:',
'LBL_SELECTED_COLUMNS'=>'Selected Columns:',
'LBL_ADD_BUTTON'=>'Add',
'LBL_COLUMNS'=>'Columns',
'LBL_COLUMNS_SUM'=>'Sum',
'LBL_COLUMNS_AVERAGE'=>'Average',
'LBL_COLUMNS_LOW_VALUE'=>'Lowest Value',
'LBL_COLUMNS_LARGE_VALUE'=>'Largest Value',
'LBL_NONE'=>'None',
'LBL_GROUPING_SORT'=>'Sort Order:',
'LBL_GROUPING_SUMMARIZE'=>'Summarize information by:',
'LBL_GROUPING_THEN_BY'=>'and then by:',
'LBL_GROUPING_FINALLY_BY'=>'and finally by:',
'LBL_ADVANCED_FILTER'=>'Advanced Filters',
'LBL_STANDARD_FILTER'=>'Standard Filters',
'LBL_SF_COLUMNS'=>'Column',
'LBL_SF_STARTDATE'=>'Start Date',
'LBL_SF_ENDDATE'=>'End Date',
'LBL_AF_HDR1'=>'Set the search conditions to further restrict the list.',
'LBL_AF_HDR2'=>'You can use &quot;or&quot; filters by entering multiple items in the third column.',
'LBL_AF_HDR3'=>'You can enter up to 10 items, separated by commas. For example: CA, NY, TX, FL searches for CA or NY or TX or FL.',
'LBL_FILTER_OPTIONS'=>'Filter Options',
'LBL_CUSTOMIZE_BUTTON'=>'Customize',
'LBL_EXPORTPDF_BUTTON'=>'Export To PDF',
'LBL_APPLYFILTER_BUTTON'=>'Apply Filter',
'LBL_GENERATED_REPORT'=>'Generated Report',
'LBL_GRAND_TOTAL'=>'Grand Total',

//Added for 4.2 Patch I
'LBL_EXPORTXL_BUTTON'=>'Export To Excel',

//Added for 5 Beta
'LBL_NO_PERMISSION'=>'Your profile dosen\'t allow you view the reports for one of the  module(s)',
'LBL_SELECT_COLUMNS_TO_GENERATE_REPORTS'=>'Select columns to generate reports',
'LBL_AVAILABLE_FIELDS'=>'Available Fields',
'LBL_SELECTED_FIELDS'=>'Selected Fields',
'LBL_CALCULATIONS'=>'Calculations',
'LBL_SELECT_COLUMNS_TO_TOTAL'=>'Select columns to Total',
'LBL_SELECT_FILTERS_TO_STREAMLINE_REPORT_DATA'=>'Select Filters to Streamline Report Data',
'LBL_SELECT_FILTERS'=>'Filters',
'LBL_SELECT_COLUMNS_TO_GROUP_REPORTS'=>'Select columns to group reports',
'LBL_BACK_TO_REPORTS'=>'Back to Reports',
'LBL_SELECT_ANOTHER_REPORT'=>'Select Another Report',
'LBL_SELECT_COLUMN'=>'Select Column',
'LBL_SELECT_TIME'=>'Select Time',
'LBL_PRINT_REPORT'=>'Print Report',
'LBL_CLICK_HERE'=>'Click Here',
'LBL_TO_ADD_NEW_GROUP'=>'to add new folder',
'LBL_CREATE_NEW'=>'Create New',
'LBL_RELATIVE_MODULE'=>'Related Module',
'LBL_REPORT_TYPE'=>'Report Type',
'LBL_REPORT_DETAILS'=>'Report Details',
'LBL_TYPE_THE_NAME'=>'Type the Name',
'LBL_DESCRIPTION_FOR_REPORT'=>'Description for the report',
'LBL_REPORT_NAME'=>'Report Name',
'LBL_DESCRIPTION'=>'Description',
'LBL_TOOLS'=>'Tools',
'LBL_AND'=>'and',
'LBL_ADD_NEW_GROUP'=>'Add New Folder',
'LBL_REPORT_MODULE'=>'Report Module',
'LBL_SELECT_RELATIVE_MODULE_FOR_REPORT'=>'Select Related Module for Report',
'LBL_SELECT_REPORT_TYPE_BELOW'=>'Select Report type Below',
'LBL_TABULAR_FORMAT'=>'Tabular Format',
'LBL_TABULAR_REPORTS_ARE_SIMPLEST'=>'Tabular Reports are the simplest and fastest way of getting your data',
'LBL_SUMMARY_REPORT_VIEW_DATA_WITH_SUBTOTALS'=>'Summary reports allow you to view your data along with subtotals and other summary information',
'LBL_FILTERS'=>'Filters',
'LBL_MOVE_TO'=>'Move to',
'LBL_RENAME_FOLDER'=>'Rename Folder',
'LBL_DELETE_FOLDER'=>'Delete Folder',

'Account and Contact Reports'=>'Organization and Contact Reports',
'Lead Reports'=>'Lead Reports',
'Potential Reports'=>'Opportunity Reports',
'Activity Reports'=>'Activity Reports',
'HelpDesk Reports'=>'Trouble Tickets Reports',
'Product Reports'=>'Product Reports',
'Quote Reports'=>'Quote Reports',
'PurchaseOrder Reports'=>'PurchaseOrder Reports',
'SalesOrder Reports'=>'SalesOrder Reports', //Added for SO
'Invoice Reports'=>'Invoice Reports',
'Campaign Reports'=>'Campaign Reports', //Added for Campaigns
'Contacts by Accounts'=>'Contacts by Organizations',
'Contacts without Accounts'=>'Contacts without Organizations',
'Contacts by Potentials'=>'Contacts by Opportunities',
'Contacts related to Accounts'=>'Contacts related to Organizations',
'Contacts not related to Accounts'=>'Contacts not related to Organizations',
'Contacts related to Potentials'=>'Contacts related to Opportunities',
'Lead by Source'=>'Lead by Source',
'Lead Status Report'=>'Lead Status Report',
'Potential Pipeline'=>'Opportunity Pipeline',
'Closed Potentials'=>'Closed Opportunities',
'Potential that have Won'=>'Opportunity that have Won',
'Tickets by Products'=>'Tickets by Products',
'Tickets by Priority'=>'Tickets by Priority',
'Open Tickets'=>'Open Tickets',
'Tickets related to Products'=>'Tickets related to Products',
'Tickets that are Open'=>'Tickets that are Open',
'Product Details'=>'Product Details',
'Products by Contacts'=>'Products by Contacts',
'Product Detailed Report'=>'Product Detailed Report',
'Products related to Contacts'=>'Products related to Contacts',
'Open Quotes'=>'Open Quotes',
'Quotes Detailed Report'=>'Quotes Detailed Report',
'Quotes that are Open'=>'Quotes that are Open',
'PurchaseOrder by Contacts'=>'PurchaseOrder by Contacts',
'PurchaseOrder Detailed Report'=>'PurchaseOrder Detailed Report',
'PurchaseOrder related to Contacts'=>'PurchaseOrder related to Contacts',
'Invoice Detailed Report'=>'Invoice Detailed Report',
'Last Month Activities'=>'Last Month Activities',
'This Month Activities'=>'This Month Activities',
'Campaign Expectations and Actuals'=>'Campaign Expectations and Actuals', //Added for Campaigns
'SalesOrder Detailed Report'=>'SalesOrder Detailed Report', //Added for SO

'LBL_DELETE'=>'Delete',
'Create_Reports'=>'Create Reports',
'Create_New_Folder'=>'Create New Folder',
'Move_Reports'=>'Move Reports',
'Delete_Report'=>'Delete Report',

'Custom'=>'Custom',
'Previous FY'=>'Previous FY',
'Current FY'=>'Current FY',
'Next FY'=>'Next FY',
'Previous FQ'=>'Previous FQ',
'Current FQ'=>'Current FQ',
'Next FQ'=>'Next FQ',
'Yesterday'=>'Yesterday',
'Today'=>'Today',
'Tomorrow'=>'Tomorrow',
'Last Week'=>'Last Week',
'Current Week'=>'Current Week',
'Next Week'=>'Next Week',
'Last Month'=>'Last Month',
'Current Month'=>'Current Month',
'Next Month'=>'Next Month',
'Last 7 Days'=>'Last 7 Days',
'Last 30 Days'=>'Last 30 Days',
'Last 60 Days'=>'Last 60 Days',
'Last 90 Days'=>'Last 90 Days',
'Last 120 Days'=>'Last 120 Days',
'Next 7 Days'=>'Next 7 Days',
'Next 30 Days'=>'Next 30 Days',
'Next 60 Days'=>'Next 60 Days',
'Next 90 Days'=>'Next 90 Days',
'Next 120 Days'=>'Next 120 Days',
'TITLE_VTIGERCRM_CREATE_REPORT' => 'vtiger CRM - Create Report',
'TITLE_VTIGERCRM_PRINT_REPORT' => 'vtiger -  Print Report',
'NO_FILTER_SELECTED' => 'No filter Selected',

'LBL_GENERATE_NOW'=>'Generate Now',
'Totals'=>'Field Names',
'SUM'=>'SUM',
'AVG'=>'AVG',
'MAX'=>'MAX',
'MIN'=>'MIN',
'LBL_CUSTOM_REPORTS'=>'Custom Reports',

'ticketid'=>'Ticket Id',
'NO_COLUMN'=>'No Columns available to Total',

// Added/Updated for vtiger CRM 5.0.4
'LBL_REPORT_DELETED' => 'The report you are trying to view has been deleted.',

//Added for Reports
'LBL_SHARING'=>'Sharing',
'SELECT_FILTER_TYPE'=>'Select Report Type',
'LBL_USERS'=>'Users',
'LBL_GROUPS'=>'Groups',
'LBL_SELECT_FIELDS'=>'Select Fields',
'LBL_MEMBERS'=>'Members',
'LBL_RELATED_FIELDS'=>'Related Fields',
'LBL_NO_ACCESS'=>' Access Denied for module(s) ',
'LBL_NOT_ACTIVE'=>' Access Denied for module(s) ',
'LBL_PERM_DENIED'=>' Permission Denied for Report(s): ',
'LBL_FLDR_NOT_EMPTY'=>'Folder you are trying to delete is not Empty, Move or Delete the Reports in it.',
'NO_REL_MODULES'=>'No Related Modules for the Selected Module',
'LBL_REPORT_GENERATION_FAILED'=>'Report generation failed!',

'LBL_OR'=>'or',
'LBL_NEW_GROUP'=>'New Group',
'LBL_DELETE_GROUP'=>'Delete Group',
'LBL_NEW_CONDITION'=>'New Condition',
'LBL_SHARING_TYPE'=>'Sharing Type',
'LBL_SELECT_REPORT_TYPE_TO_CONTROL_ACCESS'=>'Select Sharing Type to Control Access to the Report',
'LBL_ACTION' => 'Action',
'LBL_VIEW_DETAILS' => 'View Details',
'LBL_SHOW_STANDARD_FILTERS' => 'Show Standard Filters',
'LBL_YEAR' => 'Year',
'LBL_MONTH'=> 'Month',
'LBL_QUARTER'=> 'Quarter',
'LBL_NONE'=> 'None',

'LBL_ROLES'=>'Roles',
'LBL_ROLES_SUBORDINATES'=>'Roles and Subordinates',
'LBL_SCHEDULE_EMAIL'=>'Schedule Email',
'LBL_SCHEDULE_EMAIL_DESCRIPTION'=>'Schedule Report to be sent to the selected Recipients at regular intervals through email',
'LBL_USERS_AVAILABEL'=> 'Recipients',
'LBL_REPORT_FORMAT_PDF'=> 'PDF',
'LBL_REPORT_FORMAT_EXCEL'=> 'EXCEL',
'LBL_REPORT_FORMAT_BOTH'=> 'Both',
'LBL_REPORT_FORMAT'=> 'Report Format',
'LBL_USERS_SELECTED'=>'Selected Recipients',
'LBL_SELECT'=>'Select',
'Hourly'=>'Hourly',
'Daily'=>'Daily',
'Weekly'=>'Weekly',
'BiWeekly'=>'BiWeekly',
'Monthly'=>'Monthly',
'Annually'=>'Annually',
'LBL_SCHEDULE_REPORT'=>'Schedule Report',
'LBL_SCHEDULE_FREQUENCY'=>'Frequency',
'OPTION_SCHEDULE_EMAIL_CHOOSE'=>'Choose ..... ',
'LBL_SCHEDULE_EMAIL_TIME'=>'Time',
'LBL_SCHEDULE_EMAIL_DOW'=>'DOW',
'LBL_SCHEDULE_EMAIL_DAY'=>'Day',
'LBL_SCHEDULE_EMAIL_MONTH'=>'Month',
'WEEKDAY_STRINGS' => array('Sunday','Monday','Tuesday','Wednesday','Thursday','Friday','Saturday'),
'MONTH_STRINGS' => array('January','February','March','April','May','June','July','August','September','October','November','December'),

'LBL_AUTO_GENERATED_REPORT_EMAIL' => 'This is an auto-generated email sent on behalf of a scheduled report.',
'LBL_TIME_FORMAT_MSG' => 'hh:mm (24 hour format)',

'LBL_SAVE_REPORT' => 'Save',
'LBL_SAVE_REPORT_AS' => 'Save Report as...',

//Report Charts
'LBL_VIEW_CHARTS' => 'View Charts',
'LBL_ADD_CHARTS' => 'Add Chart To HomePage',
'LBL_HOME_REPORT_NAME' => 'Report Name',
'LBL_HOME_HORIZONTAL_BARCHART' => 'Horizontal BarChart',
'LBL_HOME_VERTICAL_BARCHART' => 'Vertical BarChart',
'LBL_HOME_PIE_CHART' => 'Pie Chart',
'LBL_HOME_REPORT_TYPE' => 'Report Type',
'LBL_HOME_WINDOW_TITLE' => 'Window Title',
'LBL_GROUPING_TIME' => 'Group By Time',
'LBL_WIDGET_ADDED' => 'Widget Added Successfully.',
'LBL_UNDEFINED' => 'Undefined',
)

?>
